@@ -1,5 +1,5 @@
 from web_foundation.kernel.isolate import *
-from web_foundation.kernel.channel import *
+from web_foundation.kernel.messaging.channel import *
 
 __all__ = ("Isolate",
            "IChannel",
